## 0.10.8.2 (2023-02-02)

Manual changes of `Any` union to `Incomplete` in stubs folder (#9566)

- ClassVar[Any | None]
- Missed previous changes due to alias
- Manual review of leftover Any unions (`| Any` and `Any |`)

## 0.10.8.1 (2022-11-13)

Mark `toml` as complete (#9185)

## 0.10.8 (2022-07-12)

Import `Match` and `Pattern` from `re`, not `typing` (#8277)

## 0.10.7 (2022-05-07)

Import generics from standard modules in all third-party stubs (#7791)

## 0.10.6 (2022-04-27)

Remove Python 2 support from toml (#7713)

## 0.10.5 (2022-04-16)

Use `TypeAlias` where possible for type aliases (#7630)

## 0.10.4 (2022-02-10)

Improve `toml` typings (#7146)

Co-authored-by: Akuli <akuviljanen17@gmail.com>

## 0.10.3 (2022-01-08)

Use lowercase `type` everywhere (#6853)

## 0.10.1 (2021-10-12)

Add star to all non-0.1 versions (#6146)

## 0.10.0 (2021-09-19)

Update third-party package versions (#5996)

